==> dl.php?src=linea21_1_0.zip: linea21/newsletter/mod.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


if (isset($_GET['id']))	$id=$_GET['id'];
if (isset($_POST['id'])) $id=$_POST['id'];

$newsletter_object = new newsletter;

$mask_statut_D='';
$mask_statut_W='';



if(isset($_POST['enregistrer'])) {
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$newsletter_object->ModifyNewsletter($id, $data_table, $sql_object);	
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

// Titre de la newsletter en cours de modification
$requete=SQL_getNewsletterTitle($id);
$result=$sql_object->DBSelect($requete);
if($result==0 || count($result)!=1) exit;
else $news_current_title=formatText($result[0]['newsletter_title'],'2HTML');


// Obtention des donnes  de la BDD
$req_det= SQL_getoneCompleteNewsletter($id);
$result=$sql_object->DBSelect($req_det);
if($result==0 || count($result)!=1) exit;

$form_title=formatText($result[0]['newsletter_title'], '2FIELD');
$form_body=formatText($result[0]['newsletter_body'], '2FIELD');
$form_statut=$result[0]['newsletter_statut'];
$news_owner = $result[0]['newsletter_posted_by'];

//////////// Check Droits utilisateur + statut newsletter courante ////////////
if (!IsSuperAdmin() || $form_statut=='P') ReloadIndex('admin');
////////////

if(isset($_POST['valider'])) {
	$table[0]=$_POST['newsletter_title'];
	$table[1]=$_POST['newsletter_body'];
	$table[2]=$_POST['newsletter_statut'];
	
	$integrity=$newsletter_object->CheckDataIntegrity($table);
	
	if(is_string($integrity)) $text_format='2FIELD';
	else $text_format='2HTML';
	$form_title=formatText($_POST['newsletter_title'],$text_format);
	$form_body=formatText($_POST['newsletter_body'], $text_format);
	$form_statut=$_POST['newsletter_statut'];
	

	if($_POST['newsletter_statut']=='D') $mask_statut_D='checked="checked"'; else $mask_statut_D='';
	if($_POST['newsletter_statut']=='P') $mask_statut_P='checked="checked"'; else $mask_statut_W='';
	$table=urlencode(serialize($table));
}

// radio statut
if($form_statut=='W') $mask_statut_W='checked="checked"';
if($form_statut=='D') $mask_statut_D='checked="checked"';



?>


<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['news'];?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['newsletter']['mod']. ' : '.$news_current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($news_current_title); ?></h2>
			<form id="modnews" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="newsletter_title"><? echo $GLOBALS['lang']['newsletter']['title']; ?> : *</label>
				<input name="newsletter_title" type="text" class="textfield" id="newsletter_title" maxlength="150" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="newsletter_body"><? echo $GLOBALS['lang']['newsletter']['body']; ?> : *</label>
				<textarea id="newsletter_body" name="newsletter_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<label for="statut_W" ><? echo $GLOBALS['lang']['newsletter']['statut']; ?> : </label>
				<input name="newsletter_statut" type="radio" id="statut_D" value="D" <?php echo $mask_statut_D; ?> /><span class="radio"><?php echo display_statut('D'); ?></span>
				<input name="newsletter_statut" type="radio" id="statut_W" value="W" <?php echo $mask_statut_W; ?> /><span class="radio"><?php echo $GLOBALS['lang']['newsletter']['nightsend']; ?></span>
				<br />
				</p>
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<?php echo cancel_button('javascript:history.go(-1);'); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid']; ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Rcapitulatif
} else	{
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo formatTitleh2($GLOBALS['lang']['recap']['title']); ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['newsletter']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['newsletter']['body']." :</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['divers']['statut'] ."</dt>\n";
			echo "<dd>". display_statut($_POST['newsletter_statut']). "</dd>\n";
			echo "</dl>\n";
			?>
			<form id="modscale" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<?php echo cancel_button('?rub=news&amp;todo=list'); ?>
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview']; ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save']; ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>

==> dl.php?src=linea21_1_1.zip: linea21/newsletter/mod.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


if (isset($_GET['id']))	$id=$_GET['id'];
if (isset($_POST['id'])) $id=$_POST['id'];

$newsletter_object = new newsletter;

$mask_statut_D='';
$mask_statut_W='';



if(isset($_POST['enregistrer'])) {
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$newsletter_object->ModifyNewsletter($id, $data_table, $sql_object);	
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo;
	if($result) header("Location: ".$link_confirm);
	else  system_error();
}

// Titre de la newsletter en cours de modification
$requete=SQL_getNewsletterTitle($id);
$result=$sql_object->DBSelect($requete);
if($result==0 || count($result)!=1) exit;
else $news_current_title=formatText($result[0]['newsletter_title'],'2HTML');


// Obtention des données  de la BDD
$req_det= SQL_getoneCompleteNewsletter($id);
$result=$sql_object->DBSelect($req_det);
if($result==0 || count($result)!=1) exit;

$form_title=formatText($result[0]['newsletter_title'], '2FIELD');
$form_body=formatText($result[0]['newsletter_body'], '2FIELD');
$form_statut=$result[0]['newsletter_statut'];
$news_owner = $result[0]['newsletter_posted_by'];

//////////// Check Droits utilisateur + statut newsletter courante ////////////
if (!IsSuperAdmin() || $form_statut=='P') ReloadIndex('admin');
////////////

if(isset($_POST['valider'])) {
	$table[0]=$_POST['newsletter_title'];
	$table[1]=$_POST['newsletter_body'];
	$table[2]=$_POST['newsletter_statut'];
	
	$integrity=$newsletter_object->CheckDataIntegrity($table);
	
	if(is_string($integrity)) $text_format='2FIELD';
	else $text_format='2HTML';
	$form_title=formatText($_POST['newsletter_title'],$text_format);
	$form_body=formatText($_POST['newsletter_body'], $text_format);
	$form_statut=$_POST['newsletter_statut'];
	

	if($_POST['newsletter_statut']=='D') $mask_statut_D='checked="checked"'; else $mask_statut_D='';
	if($_POST['newsletter_statut']=='P') $mask_statut_P='checked="checked"'; else $mask_statut_W='';
	$table=urlencode(serialize($table));
}

// radio statut
if($form_statut=='W') $mask_statut_W='checked="checked"';
if($form_statut=='D') $mask_statut_D='checked="checked"';



?>


<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home']; ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu']['news'];?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['newsletter']['mod']. ' : '.$news_current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($news_current_title); ?></h2>
			<form id="modnews" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="newsletter_title"><? echo $GLOBALS['lang']['newsletter']['title']; ?> : *</label>
				<input name="newsletter_title" type="text" class="textfield" id="newsletter_title" maxlength="200" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="newsletter_body"><? echo $GLOBALS['lang']['newsletter']['body']; ?> : *</label>
				<textarea id="newsletter_body" name="newsletter_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<label for="statut_W" ><? echo $GLOBALS['lang']['newsletter']['statut']; ?> : </label>
				<input name="newsletter_statut" type="radio" id="statut_D" value="D" <?php echo $mask_statut_D; ?> /><span class="radio"><?php echo display_statut('D'); ?></span>
				<input name="newsletter_statut" type="radio" id="statut_W" value="W" <?php echo $mask_statut_W; ?> /><span class="radio"><?php echo $GLOBALS['lang']['newsletter']['nightsend']; ?></span>
				<br />
				</p>
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<?php echo cancel_button('javascript:history.go(-1);'); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid']; ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Récapitulatif
} else	{
?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo formatTitleh2($GLOBALS['lang']['recap']['title']); ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['newsletter']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['newsletter']['body']." :</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['divers']['statut'] ."</dt>\n";
			echo "<dd>". display_statut($_POST['newsletter_statut']). "</dd>\n";
			echo "</dl>\n";
			?>
			<form id="modscale" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="id" type="hidden" value="<?php echo $id; ?>" id="id" />
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<?php echo cancel_button('?rub=news&amp;todo=list'); ?>
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview']; ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save']; ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>
